@@ -22,6 +22,10 @@
 #  include <config.h>
 #endif
 
+#include <string.h>
+
+#include <glib/gi18n.h>
+
 #include "hosts.h"
 #include "gst.h"
 #include "gst-network-tool.h"
@@ -91,6 +95,7 @@ add_list_columns (GtkTreeView *list)
 					       NULL);
 
   renderer = gtk_cell_renderer_text_new ();
+  g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
   gtk_tree_view_insert_column_with_attributes (list, -1,
 					       _("Aliases"),
 					       renderer,
@@ -179,10 +184,13 @@ host_aliases_add_from_xml (xmlNodePtr node)
       g_free (str);
     }
 
-  host_aliases_add (address, aliases->str);
+  if (address && aliases)
+    host_aliases_add (address, aliases->str);
 
   g_free (address);
-  g_string_free (aliases, TRUE);
+
+  if (aliases)
+    g_string_free (aliases, TRUE);
 }
 
 void
@@ -232,6 +240,35 @@ host_aliases_clear (void)
   gtk_list_store_clear (GTK_LIST_STORE (model));
 }
 
+void
+host_aliases_check_fields (void)
+{
+  GtkWidget     *address, *aliases, *ok_button;
+  GtkTextBuffer *buffer;
+  GtkTextIter    start, end;
+  gboolean       valid;
+  const gchar   *addr;
+  gchar         *str;
+  gint           address_type;
+
+  address   = gst_dialog_get_widget (tool->main_dialog, "host_alias_address");
+  aliases   = gst_dialog_get_widget (tool->main_dialog, "host_alias_list");
+  ok_button = gst_dialog_get_widget (tool->main_dialog, "host_alias_ok_button");
+
+  buffer  = gtk_text_view_get_buffer (GTK_TEXT_VIEW (aliases));
+  gtk_text_buffer_get_bounds (buffer, &start, &end);
+  str = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
+
+  addr = gtk_entry_get_text (GTK_ENTRY (address));
+  address_type = gst_filter_check_ip_address (addr);
+
+  valid = ((address_type == GST_ADDRESS_IPV4 || address_type == GST_ADDRESS_IPV6)
+	   && (str && *str));
+  gtk_widget_set_sensitive (ok_button, valid);
+
+  g_free (str);
+}
+
 static void
 host_aliases_dialog_prepare (GtkTreeIter *iter)
 {
@@ -269,6 +306,8 @@ host_aliases_dialog_prepare (GtkTreeIter *iter)
       gtk_entry_set_text (GTK_ENTRY (address), "");
       gtk_text_buffer_set_text (buffer, "", -1);
     }
+
+  host_aliases_check_fields ();
 }
 
 void
